---
title: Browser Use
---

AG2 now integrates [Browser Use](https://browser-use.com), allowing your agents to navigate websites, extract dynamic content, and interact with web pages. This makes automated data collection, web automation, and other tasks easier and more efficient.

![Browser Use Example](/docs/user-guide/reference-agents/assets/websurferagent_animated.gif)

import BrowserUse from "/snippets/reference-tools/browser-use.mdx";

<BrowserUse/>
